@@ -88,7 +88,7 @@ conf.registerChannelValue(ShrinkUrl, 'outFilter',
     URLs of outgoing messages if those URLs are longer than
     supybot.plugins.ShrinkUrl.minimumLength.""")))
 conf.registerChannelValue(ShrinkUrl, 'default',
-    ShrinkService('ln', _("""Determines what website the bot will use when
+    ShrinkService('x0', _("""Determines what website the bot will use when
     shrinking a URL.""")))
 conf.registerGlobalValue(ShrinkUrl, 'bold',
     registry.Boolean(True, _("""Determines whether this plugin will bold
