@@ -463,7 +463,7 @@ registerChannelValue(supybot.reply, 'withNotice',
 
 # XXX: User value.
 registerGlobalValue(supybot.reply, 'withNoticeWhenPrivate',
-    registry.Boolean(False, _("""Determines whether the bot will reply with a
+    registry.Boolean(True, _("""Determines whether the bot will reply with a
     notice when it is sending a private message, in order not to open a /query
     window in clients.  This can be overridden by individual users via the user
     configuration variable reply.withNoticeWhenPrivate.""")))
@@ -693,7 +693,7 @@ registerGroup(supybot.commands, 'defaultPlugins',
     commands."""))
 registerGlobalValue(supybot.commands.defaultPlugins, 'importantPlugins',
     registry.SpaceSeparatedSetOfStrings(
-        ['Admin', 'Channel', 'Config', 'Misc', 'Owner', 'Plugin', 'User'],
+        ['Admin', 'Channel', 'Config', 'Misc', 'Owner', 'User'],
         _("""Determines what plugins automatically get precedence over all
         other plugins when selecting a default plugin for a command.  By
         default, this includes the standard loaded plugins.  You probably
@@ -717,7 +717,7 @@ registerGlobalValue(supybot.abuse.flood, 'command',
 registerGlobalValue(supybot.abuse.flood.command, 'maximum',
     registry.PositiveInteger(12, _("""Determines how many commands users are
     allowed per minute.  If a user sends more than this many commands in any
-    60 second period, he or she will be ignored for
+    60 second period, they will be ignored for
     supybot.abuse.flood.command.punishment seconds.""")))
 registerGlobalValue(supybot.abuse.flood.command, 'punishment',
     registry.PositiveInteger(300, _("""Determines how many seconds the bot
@@ -729,7 +729,7 @@ registerGlobalValue(supybot.abuse.flood.command, 'invalid',
 registerGlobalValue(supybot.abuse.flood.command.invalid, 'maximum',
     registry.PositiveInteger(5, _("""Determines how many invalid commands users
     are allowed per minute.  If a user sends more than this many invalid
-    commands in any 60 second period, he or she will be ignored for
+    commands in any 60 second period, they will be ignored for
     supybot.abuse.flood.command.invalid.punishment seconds.  Typically, this
     value is lower than supybot.abuse.flood.command.maximum, since it's far
     less likely (and far more annoying) for users to flood with invalid
@@ -1054,7 +1054,7 @@ class Banmask(registry.SpaceSeparatedSetOfStrings):
         return ircutils.joinHostmask(bnick, buser, bhost)
 
 registerChannelValue(supybot.protocols.irc, 'banmask',
-    Banmask(['user', 'host'], _("""Determines what will be used as the
+    Banmask(['host'], _("""Determines what will be used as the
     default banmask style.""")))
 
 registerGlobalValue(supybot.protocols.irc, 'strictRfc',
